@@ -10,7 +10,7 @@ use Shell::Carapace;
 use String::ShellQuote;
 use JSON::MaybeXS;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 =head1 NAME
 
@@ -21,15 +21,15 @@ Chef::Knife::Cmd - A small wrapper around the Chef 'knife' command line utility
     use Chef::Knife::Cmd;
 
     my $knife = Chef::Knife::Cmd->new(
-        verbose   => 1,           # tee output to STDOUT
-        logfile   => 'knife.log', # all cmd output logged here
-        print_cmd => 1,           # if you want knife cmd printed to STDOUT
-        format    => 'json',      # all knife cmds will use --format 'json'
+        verbose   => 0,           # if true, tee output to STDOUT; default is false
+        logfile   => 'knife.log',
+        print_cmd => 1,
+        format    => 'json',      # add '--format json' to all knife commands
     );
 
     # All methods below
     # - return the output of the cmd as a string
-    # - return a hashref of the decoded json output when format => 'json'
+    # - return a hashref of the decoded json output when '--format json' is used
 
     # knife bootstrap
     $knife->bootstrap($fqdn, %options);
@@ -99,7 +99,7 @@ has verbose    => (is => 'rw', default => sub { 0 });
 has print_cmd  => (is => 'rw', default => sub { 0 });
 has noop       => (is => 'rw', default => sub { 0 });
 has shell      => (is => 'lazy');
-has logfile    => (is => 'ro', default => sub { 'knife.log' });
+has logfile    => (is => 'ro');
 has format     => (is => 'rw');
 has _json_flag => (is => 'rw');
 
@@ -115,12 +115,13 @@ sub _build_vault     { Chef::Knife::Cmd::Vault->new(knife => shift)     }
 
 sub _build_shell {
     my $self = shift;
-    return Shell::Carapace->new(
+    my $shell = Shell::Carapace->new(
         print_cmd => $self->print_cmd(),
         verbose   => $self->verbose(),
-        logfile   => $self->logfile(),
         noop      => $self->noop(),
     );
+    $shell->logfile($self->logfile) if $self->logfile();
+    return $shell;
 }
 
 sub bootstrap {
